@@ -1,5 +1,5 @@
 """
-The `~certbot_dns_selectel_v2.dns_selectel` plugin automates the process of completing
+The `~certbot_dns_selectel_v2.dns_selectel_v2` plugin automates the process of completing
 a ``dns-01`` challenge (`~acme.challenges.DNS01`) by creating, and subsequently
 removing, TXT records using the Selectel DNS API.
 
